# Table of Contents

- [base-ai-capabilities](<./base-ai-capabilities.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Base AI Capabilities](<./Base-AI-Capabilities.md>)
  - [Inventory AI Prompts](<./Base-AI-Capabilities/Inventory-AI-Prompts.md>)
  - [Using the Inventory AI Prompts](<./Base-AI-Capabilities/Using-the-Inventory-AI-Prompts.md>)
  - [AI-Assisted Text](<./Base-AI-Capabilities/AI-Assisted-Text.md>)
  - [AI-Generated Context](<./Base-AI-Capabilities/AI-Generated-Context.md>)
  - [AI-Supported Translation](<./Base-AI-Capabilities/AI-Supported-Translation.md>)
